==> haskell-binary-parser-0.5.5-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M
key: binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
abi: 506126636f4bf9f20373b4ba483394f0
exposed: True
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M
depends:
    bytestring-0.10.8.2 text-1.2.3.0 mtl-2.2.2 transformers-0.5.5.0
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.5-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-866InpOrEMPHVYzuG3f7c5
key: binary-parser-0.5.5-866InpOrEMPHVYzuG3f7c5
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
abi: d8661e20b3166e246bfbd567a0b23082
exposed: True
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
import-dirs: /usr/lib/ghc-8.6.1/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.6.1/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-866InpOrEMPHVYzuG3f7c5
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.1 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
